@@ -20,7 +20,7 @@ no warnings 'redefine';
 our ($debug, $VERSION);
 BEGIN {
 	$debug		= 0;
-	$VERSION	= '0.107';
+	$VERSION	= '0.108';
 }
 
 use Scalar::Util qw(blessed);
@@ -36,7 +36,8 @@ Returns a new model over the supplied rdf store.
 sub new {
 	my $class	= shift;
 	my $store	= shift;
-	my $self	= bless({ store => $store }, $class);
+	my %args	= @_;
+	my $self	= bless({ store => $store, %args }, $class);
 }
 
 =item C<< add_statement ( $statement [, $context] ) >>
@@ -106,7 +107,9 @@ Returns a stream object of all bindings matching the specified graph pattern.
 sub get_pattern {
 	my $self	= shift;
 	my $bgp		= shift;
-	my (@triples)	= ($bgp->isa('RDF::Trine::Statement')) ? $bgp : $bgp->triples;
+	my (@triples)	= ($bgp->isa('RDF::Trine::Statement') or $bgp->isa('RDF::Query::Algebra::Filter'))
+					? $bgp
+					: $bgp->triples;
 	unless (@triples) {
 		throw RDF::Trine::Error::CompilationError -text => 'Cannot call get_pattern() with empty pattern';
 	}
